# coding: utf-8

"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_routing.configuration import Configuration


class RouteStatistics(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'distance': 'int',
        'duration': 'int',
        'stopping_time': 'int',
        'time_window': 'RouteStatisticsTimeWindow'
    }

    attribute_map = {
        'distance': 'distance',
        'duration': 'duration',
        'stopping_time': 'stopping_time',
        'time_window': 'time_window'
    }

    def __init__(self, distance=None, duration=None, stopping_time=None, time_window=None, local_vars_configuration=None):  # noqa: E501
        """RouteStatistics - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._distance = None
        self._duration = None
        self._stopping_time = None
        self._time_window = None
        self.discriminator = None

        self.distance = distance
        self.duration = duration
        if stopping_time is not None:
            self.stopping_time = stopping_time
        if time_window is not None:
            self.time_window = time_window

    @property
    def distance(self):
        """Gets the distance of this RouteStatistics.  # noqa: E501

        Total length, in meters.  # noqa: E501

        :return: The distance of this RouteStatistics.  # noqa: E501
        :rtype: int
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this RouteStatistics.

        Total length, in meters.  # noqa: E501

        :param distance: The distance of this RouteStatistics.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and distance is None:  # noqa: E501
            raise ValueError("Invalid value for `distance`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                distance is not None and distance < 0):  # noqa: E501
            raise ValueError("Invalid value for `distance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._distance = distance

    @property
    def duration(self):
        """Gets the duration of this RouteStatistics.  # noqa: E501

        Total duration, in minutes.  # noqa: E501

        :return: The duration of this RouteStatistics.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this RouteStatistics.

        Total duration, in minutes.  # noqa: E501

        :param duration: The duration of this RouteStatistics.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and duration is None:  # noqa: E501
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                duration is not None and duration < 0):  # noqa: E501
            raise ValueError("Invalid value for `duration`, must be a value greater than or equal to `0`")  # noqa: E501

        self._duration = duration

    @property
    def stopping_time(self):
        """Gets the stopping_time of this RouteStatistics.  # noqa: E501

        The total duration of stops at points, in minutes.  # noqa: E501

        :return: The stopping_time of this RouteStatistics.  # noqa: E501
        :rtype: int
        """
        return self._stopping_time

    @stopping_time.setter
    def stopping_time(self, stopping_time):
        """Sets the stopping_time of this RouteStatistics.

        The total duration of stops at points, in minutes.  # noqa: E501

        :param stopping_time: The stopping_time of this RouteStatistics.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                stopping_time is not None and stopping_time < 0):  # noqa: E501
            raise ValueError("Invalid value for `stopping_time`, must be a value greater than or equal to `0`")  # noqa: E501

        self._stopping_time = stopping_time

    @property
    def time_window(self):
        """Gets the time_window of this RouteStatistics.  # noqa: E501


        :return: The time_window of this RouteStatistics.  # noqa: E501
        :rtype: RouteStatisticsTimeWindow
        """
        return self._time_window

    @time_window.setter
    def time_window(self, time_window):
        """Sets the time_window of this RouteStatistics.


        :param time_window: The time_window of this RouteStatistics.  # noqa: E501
        :type: RouteStatisticsTimeWindow
        """

        self._time_window = time_window

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RouteStatistics):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RouteStatistics):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_routing
from vrt_lss_routing.models.route_result import RouteResult  # noqa: E501
from vrt_lss_routing.rest import ApiException

class TestRouteResult(unittest.TestCase):
    """RouteResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RouteResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_routing.models.route_result.RouteResult()  # noqa: E501
        if include_optional :
            return RouteResult(
                tracedata = vrt_lss_routing.models.trace_data.TraceData(
                    code = 'client_server_service_time_id', ), 
                route = vrt_lss_routing.models.route.Route(
                    legs = [
                        vrt_lss_routing.models.route_leg.RouteLeg(
                            steps = [
                                vrt_lss_routing.models.route_step.RouteStep(
                                    transport_type = 'CAR', 
                                    polyline = vrt_lss_routing.models.route_polyline.RoutePolyline(
                                        points = [
                                            vrt_lss_routing.models.waypoint.Waypoint(
                                                latitude = 55.692789, 
                                                longitude = 37.554554, 
                                                duration = 15, )
                                            ], ), )
                                ], 
                            statistics = vrt_lss_routing.models.route_statistics.RouteStatistics(
                                distance = 7000, 
                                duration = 60, 
                                stopping_time = 20, 
                                time_window = vrt_lss_routing.models.route_statistics_time_window.RouteStatistics_time_window(
                                    from = '2020-10-21T09:30+03:00', 
                                    to = '2020-10-21T19:45Z', ), ), )
                        ], 
                    statistics = vrt_lss_routing.models.route_statistics.RouteStatistics(
                        distance = 7000, 
                        duration = 60, 
                        stopping_time = 20, ), )
            )
        else :
            return RouteResult(
                route = vrt_lss_routing.models.route.Route(
                    legs = [
                        vrt_lss_routing.models.route_leg.RouteLeg(
                            steps = [
                                vrt_lss_routing.models.route_step.RouteStep(
                                    transport_type = 'CAR', 
                                    polyline = vrt_lss_routing.models.route_polyline.RoutePolyline(
                                        points = [
                                            vrt_lss_routing.models.waypoint.Waypoint(
                                                latitude = 55.692789, 
                                                longitude = 37.554554, 
                                                duration = 15, )
                                            ], ), )
                                ], 
                            statistics = vrt_lss_routing.models.route_statistics.RouteStatistics(
                                distance = 7000, 
                                duration = 60, 
                                stopping_time = 20, 
                                time_window = vrt_lss_routing.models.route_statistics_time_window.RouteStatistics_time_window(
                                    from = '2020-10-21T09:30+03:00', 
                                    to = '2020-10-21T19:45Z', ), ), )
                        ], 
                    statistics = vrt_lss_routing.models.route_statistics.RouteStatistics(
                        distance = 7000, 
                        duration = 60, 
                        stopping_time = 20, ), ),
        )

    def testRouteResult(self):
        """Test RouteResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_routing.configuration import Configuration


class RoutingTask(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'waypoints': 'list[Waypoint]',
        'transport_type': 'TransportType',
        'departure_time': 'datetime',
        'result_timezone': 'int',
        'geo_provider': 'str',
        'detail': 'bool'
    }

    attribute_map = {
        'waypoints': 'waypoints',
        'transport_type': 'transport_type',
        'departure_time': 'departure_time',
        'result_timezone': 'result_timezone',
        'geo_provider': 'geo_provider',
        'detail': 'detail'
    }

    def __init__(self, waypoints=None, transport_type=None, departure_time=None, result_timezone=0, geo_provider=None, detail=True, local_vars_configuration=None):  # noqa: E501
        """RoutingTask - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._waypoints = None
        self._transport_type = None
        self._departure_time = None
        self._result_timezone = None
        self._geo_provider = None
        self._detail = None
        self.discriminator = None

        self.waypoints = waypoints
        if transport_type is not None:
            self.transport_type = transport_type
        if departure_time is not None:
            self.departure_time = departure_time
        if result_timezone is not None:
            self.result_timezone = result_timezone
        if geo_provider is not None:
            self.geo_provider = geo_provider
        if detail is not None:
            self.detail = detail

    @property
    def waypoints(self):
        """Gets the waypoints of this RoutingTask.  # noqa: E501

        Array of geographical points to calculate the distances and times between them.  # noqa: E501

        :return: The waypoints of this RoutingTask.  # noqa: E501
        :rtype: list[Waypoint]
        """
        return self._waypoints

    @waypoints.setter
    def waypoints(self, waypoints):
        """Sets the waypoints of this RoutingTask.

        Array of geographical points to calculate the distances and times between them.  # noqa: E501

        :param waypoints: The waypoints of this RoutingTask.  # noqa: E501
        :type: list[Waypoint]
        """
        if self.local_vars_configuration.client_side_validation and waypoints is None:  # noqa: E501
            raise ValueError("Invalid value for `waypoints`, must not be `None`")  # noqa: E501

        self._waypoints = waypoints

    @property
    def transport_type(self):
        """Gets the transport_type of this RoutingTask.  # noqa: E501


        :return: The transport_type of this RoutingTask.  # noqa: E501
        :rtype: TransportType
        """
        return self._transport_type

    @transport_type.setter
    def transport_type(self, transport_type):
        """Sets the transport_type of this RoutingTask.


        :param transport_type: The transport_type of this RoutingTask.  # noqa: E501
        :type: TransportType
        """

        self._transport_type = transport_type

    @property
    def departure_time(self):
        """Gets the departure_time of this RoutingTask.  # noqa: E501

        Departure date and time according to the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6).  # noqa: E501

        :return: The departure_time of this RoutingTask.  # noqa: E501
        :rtype: datetime
        """
        return self._departure_time

    @departure_time.setter
    def departure_time(self, departure_time):
        """Sets the departure_time of this RoutingTask.

        Departure date and time according to the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6).  # noqa: E501

        :param departure_time: The departure_time of this RoutingTask.  # noqa: E501
        :type: datetime
        """

        self._departure_time = departure_time

    @property
    def result_timezone(self):
        """Gets the result_timezone of this RoutingTask.  # noqa: E501

        Time zone for calculation results.  # noqa: E501

        :return: The result_timezone of this RoutingTask.  # noqa: E501
        :rtype: int
        """
        return self._result_timezone

    @result_timezone.setter
    def result_timezone(self, result_timezone):
        """Sets the result_timezone of this RoutingTask.

        Time zone for calculation results.  # noqa: E501

        :param result_timezone: The result_timezone of this RoutingTask.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                result_timezone is not None and result_timezone > 12):  # noqa: E501
            raise ValueError("Invalid value for `result_timezone`, must be a value less than or equal to `12`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                result_timezone is not None and result_timezone < -12):  # noqa: E501
            raise ValueError("Invalid value for `result_timezone`, must be a value greater than or equal to `-12`")  # noqa: E501

        self._result_timezone = result_timezone

    @property
    def geo_provider(self):
        """Gets the geo_provider of this RoutingTask.  # noqa: E501

        Geodata provider.  # noqa: E501

        :return: The geo_provider of this RoutingTask.  # noqa: E501
        :rtype: str
        """
        return self._geo_provider

    @geo_provider.setter
    def geo_provider(self, geo_provider):
        """Sets the geo_provider of this RoutingTask.

        Geodata provider.  # noqa: E501

        :param geo_provider: The geo_provider of this RoutingTask.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                geo_provider is not None and len(geo_provider) > 256):
            raise ValueError("Invalid value for `geo_provider`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                geo_provider is not None and len(geo_provider) < 1):
            raise ValueError("Invalid value for `geo_provider`, length must be greater than or equal to `1`")  # noqa: E501

        self._geo_provider = geo_provider

    @property
    def detail(self):
        """Gets the detail of this RoutingTask.  # noqa: E501

        Planning a detailed route.  # noqa: E501

        :return: The detail of this RoutingTask.  # noqa: E501
        :rtype: bool
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this RoutingTask.

        Planning a detailed route.  # noqa: E501

        :param detail: The detail of this RoutingTask.  # noqa: E501
        :type: bool
        """

        self._detail = detail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoutingTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoutingTask):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from vrt_lss_routing.models.check_result import CheckResult
from vrt_lss_routing.models.inline_response400 import InlineResponse400
from vrt_lss_routing.models.inline_response400_validations import InlineResponse400Validations
from vrt_lss_routing.models.inline_response401 import InlineResponse401
from vrt_lss_routing.models.inline_response404 import InlineResponse404
from vrt_lss_routing.models.inline_response406 import InlineResponse406
from vrt_lss_routing.models.inline_response415 import InlineResponse415
from vrt_lss_routing.models.inline_response429 import InlineResponse429
from vrt_lss_routing.models.inline_response500 import InlineResponse500
from vrt_lss_routing.models.inline_response501 import InlineResponse501
from vrt_lss_routing.models.inline_response502 import InlineResponse502
from vrt_lss_routing.models.inline_response503 import InlineResponse503
from vrt_lss_routing.models.inline_response504 import InlineResponse504
from vrt_lss_routing.models.inline_response_default import InlineResponseDefault
from vrt_lss_routing.models.matrix_result import MatrixResult
from vrt_lss_routing.models.route import Route
from vrt_lss_routing.models.route_leg import RouteLeg
from vrt_lss_routing.models.route_polyline import RoutePolyline
from vrt_lss_routing.models.route_result import RouteResult
from vrt_lss_routing.models.route_statistics import RouteStatistics
from vrt_lss_routing.models.route_statistics_time_window import RouteStatisticsTimeWindow
from vrt_lss_routing.models.route_step import RouteStep
from vrt_lss_routing.models.routing_matrix import RoutingMatrix
from vrt_lss_routing.models.routing_task import RoutingTask
from vrt_lss_routing.models.trace_data import TraceData
from vrt_lss_routing.models.transport_type import TransportType
from vrt_lss_routing.models.version_result import VersionResult
from vrt_lss_routing.models.waypoint import Waypoint



# coding: utf-8

"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_routing
from vrt_lss_routing.models.route_leg import RouteLeg  # noqa: E501
from vrt_lss_routing.rest import ApiException

class TestRouteLeg(unittest.TestCase):
    """RouteLeg unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RouteLeg
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_routing.models.route_leg.RouteLeg()  # noqa: E501
        if include_optional :
            return RouteLeg(
                steps = [
                    vrt_lss_routing.models.route_step.RouteStep(
                        transport_type = 'CAR', 
                        polyline = vrt_lss_routing.models.route_polyline.RoutePolyline(
                            points = [
                                vrt_lss_routing.models.waypoint.Waypoint(
                                    latitude = 55.692789, 
                                    longitude = 37.554554, 
                                    duration = 15, )
                                ], ), )
                    ], 
                statistics = vrt_lss_routing.models.route_statistics.RouteStatistics(
                    distance = 7000, 
                    duration = 60, 
                    stopping_time = 20, 
                    time_window = vrt_lss_routing.models.route_statistics_time_window.RouteStatistics_time_window(
                        from = '2020-10-21T09:30+03:00', 
                        to = '2020-10-21T19:45Z', ), )
            )
        else :
            return RouteLeg(
        )

    def testRouteLeg(self):
        """Test RouteLeg"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_routing
from vrt_lss_routing.models.matrix_result import MatrixResult  # noqa: E501
from vrt_lss_routing.rest import ApiException

class TestMatrixResult(unittest.TestCase):
    """MatrixResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MatrixResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_routing.models.matrix_result.MatrixResult()  # noqa: E501
        if include_optional :
            return MatrixResult(
                tracedata = vrt_lss_routing.models.trace_data.TraceData(
                    code = 'client_server_service_time_id', ), 
                matrix = {"waypoints":[{"latitude":59.9345,"longitude":30.1504},{"latitude":59.942383,"longitude":30.258951},{"latitude":59.9545,"longitude":30.2004},{"latitude":59.89527,"longitude":30.261747},{"latitude":59.9745,"longitude":30.5004}],"distances":[[0,5822,1820,14130,23304],[5936,0,4931,8365,17731],[1819,4853,0,13161,22335],[14859,9056,13854,0,21440],[21777,16306,20772,19290,0]],"durations":[[0,13,7,24,36],[13,0,9,13,25],[7,9,0,21,32],[26,14,22,0,30],[34,23,30,28,0]]}
            )
        else :
            return MatrixResult(
                matrix = {"waypoints":[{"latitude":59.9345,"longitude":30.1504},{"latitude":59.942383,"longitude":30.258951},{"latitude":59.9545,"longitude":30.2004},{"latitude":59.89527,"longitude":30.261747},{"latitude":59.9745,"longitude":30.5004}],"distances":[[0,5822,1820,14130,23304],[5936,0,4931,8365,17731],[1819,4853,0,13161,22335],[14859,9056,13854,0,21440],[21777,16306,20772,19290,0]],"durations":[[0,13,7,24,36],[13,0,9,13,25],[7,9,0,21,32],[26,14,22,0,30],[34,23,30,28,0]]},
        )

    def testMatrixResult(self):
        """Test MatrixResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_routing.configuration import Configuration


class RoutingMatrix(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'waypoints': 'list[Waypoint]',
        'distances': 'list[list]',
        'durations': 'list[list]'
    }

    attribute_map = {
        'waypoints': 'waypoints',
        'distances': 'distances',
        'durations': 'durations'
    }

    def __init__(self, waypoints=None, distances=None, durations=None, local_vars_configuration=None):  # noqa: E501
        """RoutingMatrix - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._waypoints = None
        self._distances = None
        self._durations = None
        self.discriminator = None

        self.waypoints = waypoints
        self.distances = distances
        self.durations = durations

    @property
    def waypoints(self):
        """Gets the waypoints of this RoutingMatrix.  # noqa: E501

        Array of geographical points with distances and times calculated between them.  # noqa: E501

        :return: The waypoints of this RoutingMatrix.  # noqa: E501
        :rtype: list[Waypoint]
        """
        return self._waypoints

    @waypoints.setter
    def waypoints(self, waypoints):
        """Sets the waypoints of this RoutingMatrix.

        Array of geographical points with distances and times calculated between them.  # noqa: E501

        :param waypoints: The waypoints of this RoutingMatrix.  # noqa: E501
        :type: list[Waypoint]
        """
        if self.local_vars_configuration.client_side_validation and waypoints is None:  # noqa: E501
            raise ValueError("Invalid value for `waypoints`, must not be `None`")  # noqa: E501

        self._waypoints = waypoints

    @property
    def distances(self):
        """Gets the distances of this RoutingMatrix.  # noqa: E501

        Routes length between two neighbour locations, in meters.         The values in the array are ordered according to the elements order in the `waypoints` parameter. Each matrix row is an array of distances from the desired point to every other point.   # noqa: E501

        :return: The distances of this RoutingMatrix.  # noqa: E501
        :rtype: list[list]
        """
        return self._distances

    @distances.setter
    def distances(self, distances):
        """Sets the distances of this RoutingMatrix.

        Routes length between two neighbour locations, in meters.         The values in the array are ordered according to the elements order in the `waypoints` parameter. Each matrix row is an array of distances from the desired point to every other point.   # noqa: E501

        :param distances: The distances of this RoutingMatrix.  # noqa: E501
        :type: list[list]
        """
        if self.local_vars_configuration.client_side_validation and distances is None:  # noqa: E501
            raise ValueError("Invalid value for `distances`, must not be `None`")  # noqa: E501

        self._distances = distances

    @property
    def durations(self):
        """Gets the durations of this RoutingMatrix.  # noqa: E501

        Array of route durations between two neighbour locations, in minutes. The values in the array are ordered according to the elements order in the `waypoints` parameter. Each matrix row is an array of distances from the desired point to every other point.   # noqa: E501

        :return: The durations of this RoutingMatrix.  # noqa: E501
        :rtype: list[list]
        """
        return self._durations

    @durations.setter
    def durations(self, durations):
        """Sets the durations of this RoutingMatrix.

        Array of route durations between two neighbour locations, in minutes. The values in the array are ordered according to the elements order in the `waypoints` parameter. Each matrix row is an array of distances from the desired point to every other point.   # noqa: E501

        :param durations: The durations of this RoutingMatrix.  # noqa: E501
        :type: list[list]
        """
        if self.local_vars_configuration.client_side_validation and durations is None:  # noqa: E501
            raise ValueError("Invalid value for `durations`, must not be `None`")  # noqa: E501

        self._durations = durations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoutingMatrix):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoutingMatrix):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from vrt_lss_routing.api.matrix_api import MatrixApi
from vrt_lss_routing.api.route_api import RouteApi
from vrt_lss_routing.api.system_api import SystemApi



# coding: utf-8

"""
    VeeRoute.LSS Routing

    VeeRoute.LSS Routing API  # noqa: E501

    The version of the OpenAPI document: 3.2.160181
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_routing
from vrt_lss_routing.models.route import Route  # noqa: E501
from vrt_lss_routing.rest import ApiException

class TestRoute(unittest.TestCase):
    """Route unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Route
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_routing.models.route.Route()  # noqa: E501
        if include_optional :
            return Route(
                legs = [
                    vrt_lss_routing.models.route_leg.RouteLeg(
                        steps = [
                            vrt_lss_routing.models.route_step.RouteStep(
                                transport_type = 'CAR', 
                                polyline = vrt_lss_routing.models.route_polyline.RoutePolyline(
                                    points = [
                                        vrt_lss_routing.models.waypoint.Waypoint(
                                            latitude = 55.692789, 
                                            longitude = 37.554554, 
                                            duration = 15, )
                                        ], ), )
                            ], 
                        statistics = vrt_lss_routing.models.route_statistics.RouteStatistics(
                            distance = 7000, 
                            duration = 60, 
                            stopping_time = 20, 
                            time_window = vrt_lss_routing.models.route_statistics_time_window.RouteStatistics_time_window(
                                from = '2020-10-21T09:30+03:00', 
                                to = '2020-10-21T19:45Z', ), ), )
                    ], 
                statistics = vrt_lss_routing.models.route_statistics.RouteStatistics(
                    distance = 7000, 
                    duration = 60, 
                    stopping_time = 20, 
                    time_window = vrt_lss_routing.models.route_statistics_time_window.RouteStatistics_time_window(
                        from = '2020-10-21T09:30+03:00', 
                        to = '2020-10-21T19:45Z', ), )
            )
        else :
            return Route(
        )

    def testRoute(self):
        """Test Route"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
